function [arr]=gcmfaces_interp(fld,lon,lat,method,varargin);
%object:    linearly interpolate field to given positions
%inputs:    fld is a gcmfaces field (nan-masked; up to N3,N4 dimensions)
%           lon,lat are position vectors of size Nx1
%           method may be 'polygons' (or 'TriScatteredInterp' ... via 
%              gcmfaces_interp_2d in a loop ... to be implemented later)
%optional:  (respective optional inputs ... to be implemented later)
%outputs:   fldInterp is the array of size NxN3*N4 of interpolated values
%
%note: an example below shows how to use this routine in combination
%with gcmfaces_interp_1d (for depth and time dimensions)

gcmfaces_global;

if nargin==0;
    tic;
    %a test case
    prof=MITprof_load('seals_feb2013.nc');
    dir0=fullfile(myenv.gcmfaces_dir,'sample_input',filesep,'OCCAetcONv4GRID',filesep);
    %fld=read_bin([dir0 'T_OWPv1_M_eccollc_90x50.bin'],1);
    fld=convert2gcmfaces(read2memory([dir0 'T_OWPv1_M_eccollc_90x50.bin'],[90 1170 50 12]));
    fld=repmat(mygrid.mskC,[1 1 1 12]).*fld;
    toc;
    %interpolate in space 
    tic; arr=gcmfaces_interp(fld,prof.prof_lon,prof.prof_lat,'polygons'); toc;
    %interpolate in vertical
    depIn=-mygrid.RC; depOut=prof.prof_depth;
    tic; arr2=gcmfaces_interp_1d(2,depIn,arr,depOut); toc;
    %fld2=gcmfaces_interp_1d(3,depIn,fld,depOut);
    %interpolate in time (to standard times)
    tmparr2=cat(3,arr2(:,:,12),arr2,arr2(:,:,12));
    timIn=[-0.5:1:12.5]; timOut=mod([0:36],12);
    tic; arr3=gcmfaces_interp_1d(3,timIn,tmparr2,timOut); toc;
    return;
end;

if strcmp(method,'polygons');
    ni=30; nj=30;
    map_tile=gcmfaces_loc_tile(ni,nj);
    
    loc_tile=gcmfaces_loc_tile(ni,nj,lon,lat);
    loc_tile=loc_tile.tileNo;
    [loc_interp]=gcmfaces_interp_coeffs(lon,lat,ni,nj);
    
    fld=exch_T_N(fld);
    [tmp1,tmp2,n3,n4]=size(fld{1});
    arr=NaN*zeros(length(lon),n3,n4);
    
    for ii_tile=1:max(map_tile);
        ii=find(loc_tile==ii_tile&nansum(loc_interp.w,2));
        if ~isempty(ii);
            
            %1) determine face of current tile
            tmp1=1*(map_tile==ii_tile);
            tmp11=sum(sum(tmp1,1),2); tmp12=[];
            for kk=1:tmp11.nFaces; tmp12=[tmp12,tmp11{kk}]; end;
            ii_face=find(tmp12);
            %... and its index range within face ...
            tmp1=tmp1{ii_face};
            tmp11=sum(tmp1,2);
            iiMin=min(find(tmp11)); iiMax=max(find(tmp11));
            tmp11=sum(tmp1,1);
            jjMin=min(find(tmp11)); jjMax=max(find(tmp11));
            
            %2) determine points and weights for next step
            interp_i=1+loc_interp.i(ii,:);
            interp_j=1+loc_interp.j(ii,:);
            interp_k=(interp_j-1)*(ni+2)+interp_i;%index after reshape
            interp_w=loc_interp.w(ii,:);%bininear weights
            
            %3) get the tile array
            til=fld{ii_face}(iiMin:iiMax+2,jjMin:jjMax+2,:,:);
            msk=1*(~isnan(til));
            til(isnan(til))=0;
            
            %4) interpolate each month to profile locations
            tmp1=reshape(til,[(ni+2)*(nj+2) n3 n4]);
            tmp2=reshape(msk,[(ni+2)*(nj+2) n3 n4]);
            tmp11=tmp1(interp_k(:),:); tmp11=reshape(tmp11,[size(interp_k) n3 n4]);
            tmp22=tmp2(interp_k(:),:); tmp22=reshape(tmp22,[size(interp_k) n3 n4]);
            tmp1=squeeze(sum(tmp11,2));
            tmp2=squeeze(sum(tmp22,2));
            arr(ii,:,:,:)=tmp1./tmp2;
                        
        end;%if ~isempty(ii);
    end;%for ii_tile=1:117;    
end;



